%global _find_debuginfo_opts --keep-section .rackboot

%define		major %{version}
%define		develname %mklibname %{name} -d

Name:		racket
Version:	8.17
Release:	%mkrel 1
Summary:	Racket is a Scheme implementation
License:	LGPLv2+
Group:		Development/Other
Url:		https://www.racket-lang.org/
Source0:	https://download.racket-lang.org/installers/%{version}/%{name}-%{version}-src.tgz
Source1:	racket.png
# Patches adjusted to satisfy "autosetup -p1"
Patch0:		racket-doc.patch
Patch1:		racket-fortify.patch
BuildRequires:	pkgconfig(libffi)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	imagemagick
BuildRequires:	libtool
BuildRequires:	chrpath
BuildRequires:	gcc-c++
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(liblz4)
BuildRequires:	pkgconfig(librsvg-2.0)
BuildRequires:	pkgconfig(libturbojpeg)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(pango)
BuildRequires:	pkgconfig(pixman-1)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(zlib)
# Workaround to avoid a build failure https://github.com/racket/racket/issues/4613
BuildRequires:	google-noto-sans-mono-fonts
Requires:	%{_lib}png16_16

%description
Racket is a Scheme implementation. It implements
the language as described in the Revised^5 Report on the
Algorithmic Language Scheme and adds numerous extensions.

%package -n	%{develname}
Summary:	Headers for developing programs that will use %{name}
Group:		Development/Other
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
This package contains the headers that programmers will need to develop
applications which will use %{name}.

%package -n	g%{name}
Summary:	Racket graphical Scheme implementation
Group:		Development/Other
Requires:	%{name} = %{version}
Requires:	gtk+3.0

%description -n	g%{name}
GRacket is the Racket's graphical Scheme implementation. It embeds and
extends Racket with a graphical user interface (GUI) toolbox.

%package -n	dr%{name}
Summary:	Racket graphical development environment
Group:		Development/Other
Requires:	g%{name} = %{version}

%description -n	dr%{name}
DrRacket is the graphical development environment for creating
Racket and GRacket applications.

%prep
%autosetup -p1

# Remove bundled libffi
rm -r src/bc/foreign/libffi

%build
cd src
# Docs include references to BUILDROOT, disable them as RPM otherwise rejects the build.
%configure \
	--prefix="%{_prefix}" \
	--exec-prefix="%{_prefix}" \
	--libdir=""%{_libdir}"" \
	--docdir="%{_docdir}/%{name}" \
	--enable-lt="%{_bindir}/libtool" \
	--enable-pthread \
	--enable-shared \
	--enable-libffi \
	--enable-libz \
	--enable-liblz4 \
	--enable-places \
	--disable-static \
	--disable-strip \
	--enable-sharezo

%make_build

%install
cd src
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%make_install

# correct installation
install -d -m 755 %{buildroot}%{_datadir}
install -d -m 755 %{buildroot}%{_libdir}/%{name}

# correct perms
find %{buildroot}%{_datadir}/%{name}/collects -type d -exec chmod 755 {} \;

%multiarch_includes %{buildroot}%{_includedir}/racket/*.h

for is in 16 23 48 64 96; do
  mkdir -p %{buildroot}%{_iconsdir}/hicolor/"${is}x${is}"/apps
  magick ../share/pkgs/drracket-core-lib/drracket/drracket.png -resize "${is}x${is}" \
         %{buildroot}%{_iconsdir}/hicolor/"${is}x${is}"/apps/drracket.png
  magick ../share/pkgs/slideshow-exe/slideshow/start.png -resize "${is}x${is}" \
         %{buildroot}%{_iconsdir}/hicolor/"${is}x${is}"/apps/%{name}-slideshow.png
done

# Install desktop
desktop-file-install  --set-key=StartupNotify --set-value=true --add-category IDE \
    --set-icon=drracket --dir %{buildroot}%{_datadir}/applications \
    ../share/pkgs/drracket-core-lib/drracket/drracket.desktop
desktop-file-edit --set-icon=%{name}-slideshow %{buildroot}%{_datadir}/applications/slideshow.desktop

# Install icons
mkdir -p %{buildroot}%{_iconsdir}/hicolor/scalable/apps
install -m 0644 ../share/pkgs/icons/racket-logo.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/drracket.svg

# remove references to BUILDROOT in docs
find %{buildroot} -type f | xargs sed -ri 's|%{buildroot}||g'

%files
%doc README
%{_docdir}/%{name}/*
%dir %{_sysconfdir}/%{name}
%config %{_sysconfdir}/%{name}/config.rktd
%{_datadir}/%{name}/
%{_datadir}/applications/slideshow.desktop
%{_iconsdir}/hicolor/*/apps/%{name}-slideshow.png
%{_libdir}/%{name}/
%{_bindir}/*
%{_mandir}/man1/*
%exclude %{_bindir}/gracket
%exclude %{_bindir}/drracket
%exclude %{_mandir}/man1/gracket.1*
%exclude %{_mandir}/man1/drracket.1*

%files -n %{develname}
%{_libdir}/libracketcs.a
%{_includedir}/racket/
%multiarch %{multiarch_includedir}/racket/

%files -n gracket
%{_bindir}/gracket
%{_mandir}/man1/gracket.1*

%files -n drracket
%{_bindir}/drracket
%{_mandir}/man1/drracket.1*
%{_iconsdir}/hicolor/scalable/apps/drracket.svg
%{_iconsdir}/hicolor/*/apps/drracket.png
%{_datadir}/applications/drracket.desktop


%changelog
* Fri May 23 2025 daviddavid <daviddavid> 8.17-1.mga10
+ Revision: 2185910
- new version: 8.17 (thanks to Aurelian R)

* Fri Mar 28 2025 papoteur <papoteur> 8.16-1.mga10
+ Revision: 2170619
- new version 8.16

* Sat Mar 25 2023 papoteur <papoteur> 8.8-1.mga9
+ Revision: 1950325
- new 8.8
- new 8.8
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Aug 05 2021 luigiwalser <luigiwalser> 7.5-6.mga9
+ Revision: 1739667
- rebuild for libffi

* Tue Nov 03 2020 akien <akien> 7.5-5.mga8
+ Revision: 1642359
- Disable docs to fix build
- Rebuild for libffi 3.3
+ tv <tv>
- rebuild for new libffi
+ ovitters <ovitters>
- rebuild for new ffi

* Wed Feb 19 2020 umeabot <umeabot> 7.5-2.mga8
+ Revision: 1543169
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu Jan 16 2020 shlomif <shlomif> 7.5-1.mga8
+ Revision: 1478815
- New version 7.5

* Tue May 28 2019 pterjan <pterjan> 7.3-1.mga7
+ Revision: 1399342
- Update to 7.3
- Add another upstream patch for a build failure on i586
- Add some upstream workaround which may hopefully fix the build on several architectures
- Update to 7.2
+ shlomif <shlomif>
- New version 7.1

* Sun Sep 23 2018 umeabot <umeabot> 7.0-2.mga7
+ Revision: 1300764
- Mageia 7 Mass Rebuild

* Mon Aug 20 2018 shlomif <shlomif> 7.0-1.mga7
+ Revision: 1253129
- New version 7.0

* Sat Mar 17 2018 shlomif <shlomif> 6.12-1.mga7
+ Revision: 1210157
- New version 6.12

* Tue Feb 16 2016 umeabot <umeabot> 5.3.6-7.mga6
+ Revision: 962697
- Mageia 6 Mass Rebuild

* Fri Oct 23 2015 daviddavid <daviddavid> 5.3.6-6.mga6
+ Revision: 894421
- add more docs to fix build with latest rpm

* Wed Oct 15 2014 umeabot <umeabot> 5.3.6-5.mga5
+ Revision: 742096
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 5.3.6-4.mga5
+ Revision: 725217
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 5.3.6-3.mga5
+ Revision: 688599
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 5.3.6-2.mga4
+ Revision: 535153
- Mageia 4 Mass Rebuild

* Wed Sep 18 2013 fwang <fwang> 5.3.6-1.mga4
+ Revision: 481252
- do not build shared lib, as suggested by upstream
- new version 5.3.6
- br libpng
- do not build parallel
- do not build shared lib, it is not suggested by upstream
- force libpng16
- use system ffi
- new version 5.3.5

* Sun Jan 13 2013 umeabot <umeabot> 5.3.1-3.mga3
+ Revision: 380151
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Dec 28 2012 mitya <mitya> 5.3.1-2.mga3
+ Revision: 335758
- GUIs don't work without racket itself; don't provide "racket" from libracket
- Various fixes on reqs and provides

* Thu Nov 08 2012 mitya <mitya> 5.3.1-1.mga3
+ Revision: 316509
- New version 5.3.1

* Fri Aug 24 2012 mitya <mitya> 5.3-1.mga3
+ Revision: 283397
- new version 5.3
- drop patch 0 (merged upstream)
- parallel "raco setup" works again

* Sat May 05 2012 mitya <mitya> 5.2.1-1.mga2
+ Revision: 234779
- Update to 5.2.1

* Sat May 05 2012 mitya <mitya> 5.2-1.mga2
+ Revision: 234767
- Fix build
- Import Racket 5.2
- Created package structure for racket.

